async fn federation_status(
__arg0: Extension<Arc<Gateway>>,
__arg1: Json<FederationStatusRequest>,
) -> Result<Json<Value>, GatewayError>Expand description
Reports sanitized capability and health for exactly one requested federation.
async fn federation_status(
__arg0: Extension<Arc<Gateway>>,
__arg1: Json<FederationStatusRequest>,
) -> Result<Json<Value>, GatewayError>Reports sanitized capability and health for exactly one requested federation.